@@ -35,7 +35,9 @@
 #include <fcntl.h>
 #include <stdio.h>
 #include <sys/types.h>
+#ifndef G_OS_WIN32
 #include <sys/wait.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
@@ -49,6 +51,8 @@
 extern int errno;
 #endif
 
+#ifndef G_OS_WIN32
+
 static void
 set_cloexec (gint fd)
 {
@@ -65,6 +69,8 @@ safe_read (int fd, void *buf, size_t count)
   return n;
 }
 
+#endif
+
 /**
  * gnome_execute_async_with_env_fds:
  * @dir: Directory in which child should be executed, or %NULL for current
@@ -86,6 +92,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
 				  char * const envv[], 
 				  gboolean close_fds)
 {
+#ifndef G_OS_WIN32
   int parent_comm_pipes[2], child_comm_pipes[2];
   int child_errno, itmp, i, open_max;
   gssize res;
@@ -219,6 +226,12 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
     g_message("gnome_execute_async_with_env_fds: returning %d", child_pid);
 
   return child_pid;
+#else
+  /* FIXME: Implement if needed */
+  g_warning ("gnome_execute_async_with_env_fds: Not implemented");
+
+  return -1;
+#endif
 }
 
 /**
@@ -357,6 +370,7 @@ gnome_execute_shell (const char *dir, const char *commandline)
 void
 gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 {
+#ifndef G_OS_WIN32
         char **real_argv;
         int real_argc;
         int i, j;
@@ -389,24 +403,27 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 
 	client = gconf_client_get_default ();
 	terminal = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec", NULL);
-	g_object_unref (G_OBJECT (client));
+	g_object_unref (client);
 	
 	if (terminal) {
+		gchar *command_line;
 		gchar *exec_flag;
 		exec_flag = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec_arg", NULL);
 
-		if (exec_flag == NULL) {
-			term_argc = 1;
-			term_argv = g_new0 (char *, 2);
-			term_argv[0] = terminal;
-			term_argv[1] = NULL;
-		} else {
-			term_argc = 2;
-			term_argv = g_new0 (char *, 3);
-			term_argv[0] = terminal;
-			term_argv[1] = exec_flag;
-			term_argv[2] = NULL;
-		}
+		if (exec_flag == NULL)
+			command_line = g_strdup (terminal);
+		else
+			command_line = g_strdup_printf ("%s %s", terminal,
+							exec_flag);
+
+		g_shell_parse_argv (command_line,
+				    &term_argc,
+				    &term_argv,
+				    NULL /* error */);
+
+		g_free (command_line);
+		g_free (exec_flag);
+		g_free (terminal);
 #if 0
 	    poptParseArgvString (terminal, &term_argc, &temp_argv);
 	    term_argv = g_strdupv ((gchar **) temp_argv);
@@ -465,6 +482,10 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 	/* we use g_free here as we sucked all the inner strings
 	 * out from it into real_argv */
 	g_free (term_argv);
+#else
+	/* FIXME: Implement when needed */
+	g_warning ("gnome_prepend_terminal_to_vector: Not implemented");
+#endif
 }
 
 /**
